# Date presets
LAST_7D = 'last_7d'


# Fields
FIELD_CAMPAIGN = 'campaign'
FIELD_CLICKS = 'clicks'
FIELD_DATE = 'date'
FIELD_IMPRESSIONS = 'impressions'
FIELD_MEDIUM = 'medium'
FIELD_SESSIONS = 'sessions'
FIELD_SOURCE = 'source'
FIELD_SPEND = 'spend'
